'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = captureStreams;

var _captureStreams = require('./capture-streams');

var _captureStreams2 = _interopRequireDefault(_captureStreams);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function captureStreams(runner) {
  const buffer = {
    stdout: [],
    stderr: []
  };

  let release = null;
  let test = null;
  let hook = null;

  function flushStream(stream) {
    const content = buffer[stream].join('');
    buffer[stream].length = 0;
    const target = hook || test;
    if (!target) return;
    if (!target[stream]) {
      target[stream] = content;
    } else {
      target[stream] += content;
    }
  }

  function flushStreams() {
    flushStream('stdout');
    flushStream('stderr');
  }

  runner.addListener('start', () => {
    release = [(0, _captureStreams2.default)(process.stdout, buffer.stdout), (0, _captureStreams2.default)(process.stderr, buffer.stderr)];
  });

  runner.addListener('end', () => {
    release.forEach(releaseFn => {
      releaseFn();
    });
  });

  runner.addListener('test', _test => {
    flushStreams();
    test = _test;
  });

  runner.addListener('hook', _hook => {
    flushStreams();
    hook = _hook;
  });

  const flush = runnable => {
    flushStreams();
    if (hook === runnable) {
      hook = null;
    } else if (test === runnable) {
      test = null;
    }
  };

  var _arr = ['fail', 'pass', 'pending', 'test end', 'hook end'];
  for (var _i = 0; _i < _arr.length; _i++) {
    const event = _arr[_i];
    runner.prependListener(event, flush);
  }
}