'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = writeResults;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _writeTest = require('./write-test');

var _writeTest2 = _interopRequireDefault(_writeTest);

var _writeTestsuite = require('./write-testsuite');

var _writeTestsuite2 = _interopRequireDefault(_writeTestsuite);

var _writeXml = require('./write-xml');

var _fullTitle = require('./full-title');

var _fullTitle2 = _interopRequireDefault(_fullTitle);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const trimNewLine = subject => subject && String(subject.replace(/^[\r\n]+|[\r\n]+$/g, '')) || '';

function writeResults(output, startDate, tests, cb) {
  const name = _path2.default.basename(output, _path2.default.extname(output));

  // Create directory if it doesn't exist
  (0, _mkdirp2.default)(_path2.default.dirname(output), err => {
    if (err) {
      cb(err);
      return;
    }
    const failures = tests.filter(test => test.failures.length).length;
    const skipped = tests.filter(test => !test.failures.length && test.isPending()).length;

    const writable = _fs2.default.createWriteStream(output);
    (0, _writeXml.xmlDecl)(writable);
    (0, _writeTestsuite2.default)(writable, name, startDate, tests.length, failures, skipped, () => {
      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = tests[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          const test = _step.value;

          const classname = `${name}.${(0, _fullTitle2.default)(test.parent)}`;
          const attachments = test.junitAttachments || [];
          let stdout = trimNewLine(test.stdout);
          if (test.junitAttachments) {
            if (stdout.length) stdout += '\n';
            stdout += attachments.map(filename => `[[ATTACHMENT|${filename}]]`).join('\n');
          }
          (0, _writeTest2.default)(writable, classname, test, test.failures, stdout, test.stderr);
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }
    });
    writable.end(cb);
  });
}