'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = writeTest;

var _writeStreams = require('./write-streams');

var _writeXml = require('./write-xml');

function writeTest(writable, classname, test, failures, stdout, stderr) {
  const skipped = !failures.length && test.isPending();
  const attrs = {
    classname,
    name: test.title
  };
  if (!skipped) {
    attrs.time = test.duration / 1000;
  }
  (0, _writeXml.openTag)(writable, 'testcase', attrs);
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = failures[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      const failure = _step.value;

      (0, _writeXml.openTag)(writable, 'failure', { message: failure.message });
      (0, _writeXml.text)(writable, failure.content);
      (0, _writeXml.closeTag)(writable, 'failure');
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  if (skipped) {
    (0, _writeXml.emptyTag)(writable, 'skipped');
  }
  (0, _writeStreams.writeSystemOut)(writable, stdout);
  (0, _writeStreams.writeSystemErr)(writable, stderr);
  (0, _writeXml.closeTag)(writable, 'testcase');
}