'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
/* eslint-disable class-methods-use-this */

function buildEscapes() {
  const escapes = {
    '&': '&amp;',
    "'": '&apos;',
    '"': '&quot;',
    '<': '&lt;',
    '>': '&gt;'
  };

  const regex = new RegExp(`[${Object.keys(escapes).join('')}\\x00-\\x1f]`, 'g');
  for (let i = 0; i < 32; i += 1) {
    escapes[String.fromCharCode(i)] = `&#x${i.toString(16)};`;
  }
  escapes['\t'] = '\t';
  escapes['\r'] = '\r';
  escapes['\n'] = '\n';
  return str => String(str).replace(regex, x => escapes[x]);
}

const _xmlEscape = buildEscapes();

const xmlDecl = exports.xmlDecl = stream => {
  stream.write('<?xml version="1.1"?>\n');
};

const text = exports.text = (stream, s) => {
  stream.write(_xmlEscape(s));
};

const _startTag = (stream, name, attrs = {}) => {
  stream.write(`<${name}`);
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = Object.keys(attrs)[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      const k = _step.value;

      const v = attrs[k];
      if (v != null) {
        stream.write(` ${k}="`);
        text(stream, v);
        stream.write('"');
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }
};

const openTag = exports.openTag = (stream, name, attrs) => {
  _startTag(stream, name, attrs);
  stream.write('>\n');
};

const emptyTag = exports.emptyTag = (stream, name, attrs) => {
  _startTag(stream, name, attrs);
  stream.write('/>\n');
};

const closeTag = exports.closeTag = (stream, name) => {
  stream.write(`</${name}>\n`);
};